A library for parsing and compiling zoneinfo files into time zone transition data that can be used to build TZif files or any other desired time zone format.
zoneinfo_rs offers default parsing and compiling
of zoneinfo files into time zone transition data.
Why zoneinfo_rs?
In general, this library seeks to maximally expose as much data from the zoneinfo files as possible while also supporting extra time zone database features like the zone.tab, PACKRATLIST, and POSIX time zone strings.
Modules
- compiler
- Zone info compiler functionality
- parser
- Zone info parsing implementation
- posix
- POSIX time zone types and implementation
- rule
- Zone info Rule functionality
- types
- Zoneinfo types
- zone
- Implementation of zone info’s
ZoneRecord
Structs
- Zone
Info Compiler - The compiler for turning
ZoneInfoDataintoCompiledTransitionsData - Zone
Info Data ZoneInfoDatarepresents raw unprocessed zone info data as parsed from a zone info file.- Zone
Info Parser - The primary parser for zoneinfo code points.
- Zone
TabEntry
Enums
- Zone
Info Error - The general error type for
ZoneInfooperations